PixivLiveProxyServer class

Constructors

PixivLiveProxyServer({required String url, required int port, required String serverIp})

Properties

hashCode int
The hash code for this object.
no setterinherited
originalHost String
latefinal
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server HttpServer
latefinal
serverIp String
final
url String
final

Methods

close() → void
listen() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceM3u8(String m3u8) String
replaceUri(Uri uri) Uri
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited